# apstools

Various Python tools for use with the Bluesky framework at the APS

[![release](https://img.shields.io/github/release/BCDA-APS/apstools.svg)](https://github.com/BCDA-APS/apstools/releases)
[![Python version](https://img.shields.io/pypi/pyversions/apstools.svg)](https://pypi.python.org/pypi/apstools)
[![PyPi](https://img.shields.io/pypi/v/apstools.svg)](https://pypi.python.org/pypi/apstools)
[![conda-forge](https://img.shields.io/conda/vn/conda-forge/apstools)](https://anaconda.org/conda-forge/apstools)
[![aps-anl-tag](https://img.shields.io/conda/vn/aps-anl-tag/apstools)](https://anaconda.org/aps-anl-tag/apstools)

![Unit Tests](https://github.com/BCDA-APS/apstools/workflows/Unit%20Tests/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/BCDA-APS/apstools/badge.svg?branch=main)](https://coveralls.io/github/BCDA-APS/apstools?branch=main)


## Package Information

item              | description
------------------|--------------------------------
**author**        | Pete R. Jemian
**email**         | jemian@anl.gov
**copyright**     | 2017-2022, UChicago Argonne, LLC
[**license**](LICENSE.txt) | [![license: ANL](https://img.shields.io/badge/license-ANL-brightgreen)](LICENSE.txt)
[**documentation**](https://bcda-aps.github.io/apstools/) | latest tagged release
**source**        | https://github.com/BCDA-APS/apstools


## See also
* https://BCDA-APS.github.io/apsbss
* https://blueskyproject.io/
* https://github.com/bluesky/bluesky
* https://github.com/bluesky/ophyd
* https://github.com/bluesky/databroker
* https://github.com/bluesky/hklpy
